@@ -1,5 +1,4 @@
-#!/usr/bin/perl
-
+#!/usr/bin/perl -w
 # This tests the various methods of the Graphics::Framebuffer module
 # and shows the only way threads will work with it.
 
@@ -10,9 +9,11 @@ use threads;
 use Graphics::Framebuffer;
 
 my @framebuffer;
-my $Threads = 4;
+my $Threads = $ARGV[0] || 2;
+print "\nRunning with $Threads threads\n";
+sleep 1;
 foreach my $thr (1..$Threads) {
-    push(@framebuffer,Graphics::Framebuffer->new());
+    push(@framebuffer,Graphics::Framebuffer->new('FB_DEVICE' => '/dev/fb0'));
 }
 my $screen_width = $framebuffer[0]->{'XRES'};
 my $screen_height = $framebuffer[0]->{'YRES'};
@@ -35,6 +36,7 @@ foreach my $page (1..$Threads) {
 }
 while(1) {
     threads->yield();
+    sleep 1;
 }
 
 
@@ -69,7 +71,7 @@ sub attract {
     $framebuffer[$Page]->clip_rset({'x' => 0,'y' => 0,'width' => $screen_width-1,'height' => $screen_height-1});
     switch ($type) {
         case 0 {
-            $framebuffer[$Page]->plot({'x' => $x,'y' => $y,'pixel_size' => 1});
+            $framebuffer[$Page]->plot({'x' => $x,'y' => $y,'pixel_size' => $size});
         }
         case 1 {
             $framebuffer[$Page]->plot({'x' => $x,'y' => $y,'pixel_size' => $size});
@@ -95,7 +97,7 @@ sub attract {
             }
             $framebuffer[$Page]->polygon({'pixel_size' => $size,'coordinates' => \@poly});
         }
-        else { # This can be a large memory hog.  Disabled for the moment.
+        else { # This can be a large memory hog.  Disabled (random number doesn't go this high) for the moment.
             $framebuffer[$Page]->clip_set({'x' => $x-50,'y' => $y-50,'xx' => $x+50,'yy' => $y+50});
             fill({'x' => $x,'y' => $y});
         }
